# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["CompanyLegalForm"]

CompanyLegalForm: TypeAlias = Literal[
    "ag",
    "eg",
    "ek",
    "ev",
    "ewiv",
    "foreign",
    "gbr",
    "ggmbh",
    "gmbh",
    "kg",
    "kgaa",
    "unknown",
    "llp",
    "municipal",
    "ohg",
    "se",
    "ug",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["CompanyAddress"]


class CompanyAddress(BaseModel):
    city: str
    """City or locality name. Example: "Berlin" """

    country: str
    """Country name. Example: "Germany" """

    formatted_value: str
    """
    Complete address formatted as a single string. Example: "Musterstraße 1, 10117
    Berlin, Germany"
    """

    start_date: str
    """
    Date when this address became effective. Format: ISO 8601 (YYYY-MM-DD) Example:
    "2022-01-01"
    """

    extra: Optional[str] = None
    """
    Additional address information such as c/o or attention line. Example: "c/o Max
    Mustermann"
    """

    postal_code: Optional[str] = None
    """Postal or ZIP code. Example: "10117" """

    street: Optional[str] = None
    """Street name and number. Example: "Musterstraße 1" """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["CompanyRetrieveContactResponse"]


class CompanyRetrieveContactResponse(BaseModel):
    source_url: str
    """Where the contact information was found. Example: "https://openregister.de" """

    email: Optional[str] = None
    """Company contact email address. Example: "founders@openregister.de" """

    phone: Optional[str] = None
    """Company phone number. Example: "+49 030 12345678" """

    vat_id: Optional[str] = None
    """Value Added Tax identification number.

    (Umsatzsteuer-Identifikationsnummer) Example: "DE370146530"
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .entity_type import EntityType as EntityType
from .company_name import CompanyName as CompanyName
from .company_address import CompanyAddress as CompanyAddress
from .company_capital import CompanyCapital as CompanyCapital
from .company_purpose import CompanyPurpose as CompanyPurpose
from .company_register import CompanyRegister as CompanyRegister
from .company_legal_form import CompanyLegalForm as CompanyLegalForm
from .company_register_type import CompanyRegisterType as CompanyRegisterType
from .company_retrieve_params import CompanyRetrieveParams as CompanyRetrieveParams
from .company_retrieve_response import CompanyRetrieveResponse as CompanyRetrieveResponse
from .document_retrieve_response import DocumentRetrieveResponse as DocumentRetrieveResponse
from .search_find_companies_params import SearchFindCompaniesParams as SearchFindCompaniesParams
from .search_find_companies_response import SearchFindCompaniesResponse as SearchFindCompaniesResponse
from .company_retrieve_contact_response import CompanyRetrieveContactResponse as CompanyRetrieveContactResponse
from .company_list_shareholders_response import CompanyListShareholdersResponse as CompanyListShareholdersResponse
from .search_lookup_company_by_url_params import SearchLookupCompanyByURLParams as SearchLookupCompanyByURLParams
from .search_lookup_company_by_url_response import SearchLookupCompanyByURLResponse as SearchLookupCompanyByURLResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from openregister import Openregister, AsyncOpenregister
from openregister.types import (
    CompanyRetrieveResponse,
    CompanyRetrieveContactResponse,
    CompanyListShareholdersResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCompany:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: Openregister) -> None:
        company = client.company.retrieve(
            company_id="company_id",
        )
        assert_matches_type(CompanyRetrieveResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_with_all_params(self, client: Openregister) -> None:
        company = client.company.retrieve(
            company_id="company_id",
            documents=True,
            financials=True,
            history=True,
        )
        assert_matches_type(CompanyRetrieveResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: Openregister) -> None:
        response = client.company.with_raw_response.retrieve(
            company_id="company_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        company = response.parse()
        assert_matches_type(CompanyRetrieveResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: Openregister) -> None:
        with client.company.with_streaming_response.retrieve(
            company_id="company_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            company = response.parse()
            assert_matches_type(CompanyRetrieveResponse, company, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: Openregister) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `company_id` but received ''"):
            client.company.with_raw_response.retrieve(
                company_id="",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_list_shareholders(self, client: Openregister) -> None:
        company = client.company.list_shareholders(
            "company_id",
        )
        assert_matches_type(CompanyListShareholdersResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list_shareholders(self, client: Openregister) -> None:
        response = client.company.with_raw_response.list_shareholders(
            "company_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        company = response.parse()
        assert_matches_type(CompanyListShareholdersResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list_shareholders(self, client: Openregister) -> None:
        with client.company.with_streaming_response.list_shareholders(
            "company_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            company = response.parse()
            assert_matches_type(CompanyListShareholdersResponse, company, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_list_shareholders(self, client: Openregister) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `company_id` but received ''"):
            client.company.with_raw_response.list_shareholders(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_contact(self, client: Openregister) -> None:
        company = client.company.retrieve_contact(
            "company_id",
        )
        assert_matches_type(CompanyRetrieveContactResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve_contact(self, client: Openregister) -> None:
        response = client.company.with_raw_response.retrieve_contact(
            "company_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        company = response.parse()
        assert_matches_type(CompanyRetrieveContactResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve_contact(self, client: Openregister) -> None:
        with client.company.with_streaming_response.retrieve_contact(
            "company_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            company = response.parse()
            assert_matches_type(CompanyRetrieveContactResponse, company, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve_contact(self, client: Openregister) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `company_id` but received ''"):
            client.company.with_raw_response.retrieve_contact(
                "",
            )


class TestAsyncCompany:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncOpenregister) -> None:
        company = await async_client.company.retrieve(
            company_id="company_id",
        )
        assert_matches_type(CompanyRetrieveResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncOpenregister) -> None:
        company = await async_client.company.retrieve(
            company_id="company_id",
            documents=True,
            financials=True,
            history=True,
        )
        assert_matches_type(CompanyRetrieveResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncOpenregister) -> None:
        response = await async_client.company.with_raw_response.retrieve(
            company_id="company_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        company = await response.parse()
        assert_matches_type(CompanyRetrieveResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncOpenregister) -> None:
        async with async_client.company.with_streaming_response.retrieve(
            company_id="company_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            company = await response.parse()
            assert_matches_type(CompanyRetrieveResponse, company, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncOpenregister) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `company_id` but received ''"):
            await async_client.company.with_raw_response.retrieve(
                company_id="",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_shareholders(self, async_client: AsyncOpenregister) -> None:
        company = await async_client.company.list_shareholders(
            "company_id",
        )
        assert_matches_type(CompanyListShareholdersResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list_shareholders(self, async_client: AsyncOpenregister) -> None:
        response = await async_client.company.with_raw_response.list_shareholders(
            "company_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        company = await response.parse()
        assert_matches_type(CompanyListShareholdersResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list_shareholders(self, async_client: AsyncOpenregister) -> None:
        async with async_client.company.with_streaming_response.list_shareholders(
            "company_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            company = await response.parse()
            assert_matches_type(CompanyListShareholdersResponse, company, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_list_shareholders(self, async_client: AsyncOpenregister) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `company_id` but received ''"):
            await async_client.company.with_raw_response.list_shareholders(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_contact(self, async_client: AsyncOpenregister) -> None:
        company = await async_client.company.retrieve_contact(
            "company_id",
        )
        assert_matches_type(CompanyRetrieveContactResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve_contact(self, async_client: AsyncOpenregister) -> None:
        response = await async_client.company.with_raw_response.retrieve_contact(
            "company_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        company = await response.parse()
        assert_matches_type(CompanyRetrieveContactResponse, company, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve_contact(self, async_client: AsyncOpenregister) -> None:
        async with async_client.company.with_streaming_response.retrieve_contact(
            "company_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            company = await response.parse()
            assert_matches_type(CompanyRetrieveContactResponse, company, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve_contact(self, async_client: AsyncOpenregister) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `company_id` but received ''"):
            await async_client.company.with_raw_response.retrieve_contact(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from .company import (
    CompanyResource,
    AsyncCompanyResource,
    CompanyResourceWithRawResponse,
    AsyncCompanyResourceWithRawResponse,
    CompanyResourceWithStreamingResponse,
    AsyncCompanyResourceWithStreamingResponse,
)
from .document import (
    DocumentResource,
    AsyncDocumentResource,
    DocumentResourceWithRawResponse,
    AsyncDocumentResourceWithRawResponse,
    DocumentResourceWithStreamingResponse,
    AsyncDocumentResourceWithStreamingResponse,
)

__all__ = [
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
    "CompanyResource",
    "AsyncCompanyResource",
    "CompanyResourceWithRawResponse",
    "AsyncCompanyResourceWithRawResponse",
    "CompanyResourceWithStreamingResponse",
    "AsyncCompanyResourceWithStreamingResponse",
    "DocumentResource",
    "AsyncDocumentResource",
    "DocumentResourceWithRawResponse",
    "AsyncDocumentResourceWithRawResponse",
    "DocumentResourceWithStreamingResponse",
    "AsyncDocumentResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    CompanyLegalForm,
    CompanyRegisterType,
    search_find_companies_params,
    search_lookup_company_by_url_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.company_legal_form import CompanyLegalForm
from ..types.company_register_type import CompanyRegisterType
from ..types.search_find_companies_response import SearchFindCompaniesResponse
from ..types.search_lookup_company_by_url_response import SearchLookupCompanyByURLResponse

__all__ = ["SearchResource", "AsyncSearchResource"]


class SearchResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/oregister/openregister-python#accessing-raw-response-data-eg-headers
        """
        return SearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/oregister/openregister-python#with_streaming_response
        """
        return SearchResourceWithStreamingResponse(self)

    def find_companies(
        self,
        *,
        active: bool | NotGiven = NOT_GIVEN,
        legal_form: CompanyLegalForm | NotGiven = NOT_GIVEN,
        query: str | NotGiven = NOT_GIVEN,
        register_court: str | NotGiven = NOT_GIVEN,
        register_number: str | NotGiven = NOT_GIVEN,
        register_type: CompanyRegisterType | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SearchFindCompaniesResponse:
        """Search for companies

        Args:
          active: Filter for active or inactive companies.

        Set to true for active companies only,
              false for inactive only.

          legal_form: Legal form of the company. Example: "gmbh" for "Gesellschaft mit beschränkter
              Haftung"

          query: Text search query to find companies by name. Example: "Descartes Technologies
              UG"

          register_court: Court where the company is registered. Example: "Berlin (Charlottenburg)"

          register_number: Company register number for exact matching. Example: "230633"

          register_type: Type of register to filter results. Example: "HRB" (Commercial Register B)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v0/search/company",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "active": active,
                        "legal_form": legal_form,
                        "query": query,
                        "register_court": register_court,
                        "register_number": register_number,
                        "register_type": register_type,
                    },
                    search_find_companies_params.SearchFindCompaniesParams,
                ),
            ),
            cast_to=SearchFindCompaniesResponse,
        )

    def lookup_company_by_url(
        self,
        *,
        url: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SearchLookupCompanyByURLResponse:
        """Find company by website URL

        Args:
          url: Website URL to search for.

        Example: "https://openregister.de"

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v0/search/lookup",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"url": url}, search_lookup_company_by_url_params.SearchLookupCompanyByURLParams),
            ),
            cast_to=SearchLookupCompanyByURLResponse,
        )


class AsyncSearchResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/oregister/openregister-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/oregister/openregister-python#with_streaming_response
        """
        return AsyncSearchResourceWithStreamingResponse(self)

    async def find_companies(
        self,
        *,
        active: bool | NotGiven = NOT_GIVEN,
        legal_form: CompanyLegalForm | NotGiven = NOT_GIVEN,
        query: str | NotGiven = NOT_GIVEN,
        register_court: str | NotGiven = NOT_GIVEN,
        register_number: str | NotGiven = NOT_GIVEN,
        register_type: CompanyRegisterType | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SearchFindCompaniesResponse:
        """Search for companies

        Args:
          active: Filter for active or inactive companies.

        Set to true for active companies only,
              false for inactive only.

          legal_form: Legal form of the company. Example: "gmbh" for "Gesellschaft mit beschränkter
              Haftung"

          query: Text search query to find companies by name. Example: "Descartes Technologies
              UG"

          register_court: Court where the company is registered. Example: "Berlin (Charlottenburg)"

          register_number: Company register number for exact matching. Example: "230633"

          register_type: Type of register to filter results. Example: "HRB" (Commercial Register B)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v0/search/company",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "active": active,
                        "legal_form": legal_form,
                        "query": query,
                        "register_court": register_court,
                        "register_number": register_number,
                        "register_type": register_type,
                    },
                    search_find_companies_params.SearchFindCompaniesParams,
                ),
            ),
            cast_to=SearchFindCompaniesResponse,
        )

    async def lookup_company_by_url(
        self,
        *,
        url: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SearchLookupCompanyByURLResponse:
        """Find company by website URL

        Args:
          url: Website URL to search for.

        Example: "https://openregister.de"

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v0/search/lookup",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"url": url}, search_lookup_company_by_url_params.SearchLookupCompanyByURLParams
                ),
            ),
            cast_to=SearchLookupCompanyByURLResponse,
        )


class SearchResourceWithRawResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

        self.find_companies = to_raw_response_wrapper(
            search.find_companies,
        )
        self.lookup_company_by_url = to_raw_response_wrapper(
            search.lookup_company_by_url,
        )


class AsyncSearchResourceWithRawResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

        self.find_companies = async_to_raw_response_wrapper(
            search.find_companies,
        )
        self.lookup_company_by_url = async_to_raw_response_wrapper(
            search.lookup_company_by_url,
        )


class SearchResourceWithStreamingResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

        self.find_companies = to_streamed_response_wrapper(
            search.find_companies,
        )
        self.lookup_company_by_url = to_streamed_response_wrapper(
            search.lookup_company_by_url,
        )


class AsyncSearchResourceWithStreamingResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

        self.find_companies = async_to_streamed_response_wrapper(
            search.find_companies,
        )
        self.lookup_company_by_url = async_to_streamed_response_wrapper(
            search.lookup_company_by_url,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from openregister import Openregister, AsyncOpenregister
from openregister.types import (
    SearchFindCompaniesResponse,
    SearchLookupCompanyByURLResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSearch:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_find_companies(self, client: Openregister) -> None:
        search = client.search.find_companies()
        assert_matches_type(SearchFindCompaniesResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_find_companies_with_all_params(self, client: Openregister) -> None:
        search = client.search.find_companies(
            active=True,
            legal_form="ag",
            query="query",
            register_court="register_court",
            register_number="register_number",
            register_type="HRB",
        )
        assert_matches_type(SearchFindCompaniesResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_find_companies(self, client: Openregister) -> None:
        response = client.search.with_raw_response.find_companies()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = response.parse()
        assert_matches_type(SearchFindCompaniesResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_find_companies(self, client: Openregister) -> None:
        with client.search.with_streaming_response.find_companies() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = response.parse()
            assert_matches_type(SearchFindCompaniesResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_lookup_company_by_url(self, client: Openregister) -> None:
        search = client.search.lookup_company_by_url(
            url="https://example.com",
        )
        assert_matches_type(SearchLookupCompanyByURLResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_lookup_company_by_url(self, client: Openregister) -> None:
        response = client.search.with_raw_response.lookup_company_by_url(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = response.parse()
        assert_matches_type(SearchLookupCompanyByURLResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_lookup_company_by_url(self, client: Openregister) -> None:
        with client.search.with_streaming_response.lookup_company_by_url(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = response.parse()
            assert_matches_type(SearchLookupCompanyByURLResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSearch:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_find_companies(self, async_client: AsyncOpenregister) -> None:
        search = await async_client.search.find_companies()
        assert_matches_type(SearchFindCompaniesResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_find_companies_with_all_params(self, async_client: AsyncOpenregister) -> None:
        search = await async_client.search.find_companies(
            active=True,
            legal_form="ag",
            query="query",
            register_court="register_court",
            register_number="register_number",
            register_type="HRB",
        )
        assert_matches_type(SearchFindCompaniesResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_find_companies(self, async_client: AsyncOpenregister) -> None:
        response = await async_client.search.with_raw_response.find_companies()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = await response.parse()
        assert_matches_type(SearchFindCompaniesResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_find_companies(self, async_client: AsyncOpenregister) -> None:
        async with async_client.search.with_streaming_response.find_companies() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = await response.parse()
            assert_matches_type(SearchFindCompaniesResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_lookup_company_by_url(self, async_client: AsyncOpenregister) -> None:
        search = await async_client.search.lookup_company_by_url(
            url="https://example.com",
        )
        assert_matches_type(SearchLookupCompanyByURLResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_lookup_company_by_url(self, async_client: AsyncOpenregister) -> None:
        response = await async_client.search.with_raw_response.lookup_company_by_url(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = await response.parse()
        assert_matches_type(SearchLookupCompanyByURLResponse, search, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_lookup_company_by_url(self, async_client: AsyncOpenregister) -> None:
        async with async_client.search.with_streaming_response.lookup_company_by_url(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = await response.parse()
            assert_matches_type(SearchLookupCompanyByURLResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["DocumentRetrieveResponse"]


class DocumentRetrieveResponse(BaseModel):
    id: str
    """The unique identifier for the document.

    E.g. "f47ac10b-58cc-4372-a567-0e02b2c3d479"
    """

    date: str
    """The date of the document. E.g. "2022-01-01" """

    name: str
    """The name of the document. E.g. "Musterprotokoll vom 01.01.2022" """

    type: Literal["articles_of_association", "sample_protocol", "shareholder_list"]
    """The type of document."""

    url: str
    """The URL of the document.

    It can be downloaded from there. Only valid for 15 minutes after the request.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["CompanyRetrieveParams"]


class CompanyRetrieveParams(TypedDict, total=False):
    documents: bool
    """
    Include document metadata when set to true. Lists available official documents
    related to the company.
    """

    financials: bool
    """
    Include financial data when set to true. Provides access to financial reports
    and key financial indicators.
    """

    history: bool
    """
    Include historical company data when set to true. This returns past names,
    addresses, and other changed information.
    """
